Enum Event
#[non_exhaustive]pub enum Event {
Keymap {
format: WEnum<KeymapFormat>,
fd: OwnedFd,
size: u32,
},
Key {
serial: u32,
time: u32,
key: u32,
state: WEnum<KeyState>,
},
Modifiers {
serial: u32,
mods_depressed: u32,
mods_latched: u32,
mods_locked: u32,
group: u32,
},
RepeatInfo {
rate: i32,
delay: i32,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Keymap
keyboard mapping
This event provides a file descriptor to the client which can be memory-mapped to provide a keyboard mapping description.
Fields
format: WEnum<KeymapFormat>keymap format
Key
key event
A key was pressed or released. The time argument is a timestamp with millisecond granularity, with an undefined base.
Fields
Modifiers
modifier and group state
Notifies clients that the modifier and/or group state has changed, and it should update its local state.
Fields
RepeatInfo
repeat rate and delay
Informs the client about the keyboard’s repeat rate and delay.
This event is sent as soon as the zwp_input_method_keyboard_grab_v2 object has been created, and is guaranteed to be received by the client before any key press event.
Negative values for either rate or delay are illegal. A rate of zero will disable any repeating (regardless of the value of delay).
This event can be sent later on as well with a new value if necessary, so clients should continue listening for the event past the creation of zwp_input_method_keyboard_grab_v2.
Implementations